==> CGGoogleMaps-1.4.2.tar.gz: CGGoogleMaps/function.admin_prefs_tab.php <==
<?php
#-------------------------------------------------------------------------
# Module: CGGoogleMaps - A simple module for creating google maps.
# Version: 1.0, calguy1000 <calguy1000@hotmail.com>
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/skeleton/
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
if( !isset($gCms) ) exit;
if( !$this->CheckPermission('Modify Site Preferences') )
  {
    echo $this->ShowErrors($this->Lang('error_permissiondenied'));
    return;
  }

$smarty->assign('formstart',
		$this->CGCreateFormStart($id,'admin_saveprefs',$returnid));
$smarty->assign('formend',$this->CreateFormEnd());
$smarty->assign('prompt_apikey',$this->Lang('google_api_key'));
$smarty->assign('input_apikey',$this->CreateInputText($id,'google_apikey',
						      $this->GetPreference('google_apikey',''),100,1024));
$smarty->assign('submit',$this->CreateInputSubmit($id,'submit',$this->Lang('submit')));

echo $this->ProcessTemplate('prefs_tab.php');
// EOF
?>

==> CGGoogleMaps-2.0.3.tar.gz: CGGoogleMaps/function.admin_prefs_tab.php <==
<?php
#-------------------------------------------------------------------------
# Module: CGGoogleMaps - A simple module for creating google maps.
# Version: 1.0, calguy1000 <calguy1000@hotmail.com>
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/skeleton/
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
if( !isset($gCms) ) exit;
if( !$this->CheckPermission('Modify Site Preferences') )
  {
    echo $this->ShowErrors($this->Lang('error_permissiondenied'));
    return;
  }

$smarty->assign('formstart',
		$this->CGCreateFormStart($id,'admin_saveprefs',$returnid));
$smarty->assign('formend',$this->CreateFormEnd());
$smarty->assign('prompt_apikey',$this->Lang('google_api_key'));
$smarty->assign('input_apikey',$this->CreateInputText($id,'google_apikey',
						      $this->GetPreference('google_apikey',''),100,1024));
$smarty->assign('submit',$this->CreateInputSubmit($id,'submit',$this->Lang('submit')));
$smarty->assign('lookup_services',array('GOOGLE'=>'Google','YAHOO'=>'Yahoo'));
$smarty->assign('lookup_service',$this->GetPreference('lookup_service','GOOGLE'));
$smarty->assign('lookup_policies',
		array('CACHEFIRST'=>$this->Lang('policy_cachefirst'),
		      'NOCACHE'=>$this->Lang('policy_nocache'),
		      'CACHEONLY'=>$this->Lang('policy_cacheonly')));
$smarty->assign('lookup_policy',$this->GetPreference('lookup_policy'));

echo $this->ProcessTemplate('prefs_tab.php');
// EOF
?>
